<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec></defaultcodec>
<context>
    <name>@default</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="157"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>ClockSettingDialog</name>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="13"/>
        <source>qtmclock: Setting</source>
        <translation>テーマ時計: 設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="144"/>
        <source>&amp;Close</source>
        <translation>閉じる (&amp;C)</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="80"/>
        <source>Theme Config</source>
        <translation>テーマ設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="88"/>
        <source>unload current theme.</source>
        <translation>テーマのアンロード.</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="104"/>
        <source>Unload</source>
        <translation>アンロード</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="98"/>
        <source>Theme file will be unloaded.</source>
        <translation>現在のテーマファイルを破棄し、初期フォームに戻します。</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="27"/>
        <source>Scale</source>
        <translation>拡大率</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="19"/>
        <source>View Config</source>
        <translation>外観設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="47"/>
        <source>change view scale.</source>
        <translation>表示の拡大率を変更します.</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="37"/>
        <source>100 %</source>
        <translation>100 %</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="156"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;x)</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="151"/>
        <source>Config</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="ThemeClockDraw.cpp" line="59"/>
        <source>Drop theme file in this form.</source>
        <translation>テーマファイルを、このフォームにドロップして下さい。</translation>
    </message>
</context>
<context>
    <name>ThemeClockWidget</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="276"/>
        <source>qtmclock</source>
        <translation>qtmclock</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="277"/>
        <source>%1 is not correct theme file.</source>
        <translation>%1 はテーマファイルではありません。</translation>
    </message>
</context>
</TS>
